@@ -3,7 +3,7 @@ BEGIN {
   $List::Gather::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $List::Gather::VERSION = '0.07';
+  $List::Gather::VERSION = '0.08';
 }
 # ABSTRACT: Construct lists procedurally without temporary variables
 
@@ -74,6 +74,7 @@ C<gather> returns the list of values taken during its block's execution.
 
   gather { ... }
   gather({ ... })
+  gather STMT
 
 Executes the block it has been provided with, collecting all arguments passed to
 C<take> calls within it. After execution, the list of values collected is
@@ -110,11 +111,9 @@ C<gather> block is legal.
 
 =head1 EXAMPLES
 
-  my @interesting_child_nodes = gather {
-      for my $n (@nodes) {
-          take $n->all_children
-              if $n->is_interesting;
-      }
+  my @interesting_child_nodes = gather for my $n (@nodes) {
+      take $n->all_children
+          if $n->is_interesting;
   };
 
   my @last_10_events = gather {
